summaryrefslogtreecommitdiffstats
path: root/juk/playlistsearch.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/playlistsearch.h')
-rw-r--r--juk/playlistsearch.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/juk/playlistsearch.h b/juk/playlistsearch.h
index 9b46a92c..7281ba13 100644
--- a/juk/playlistsearch.h
+++ b/juk/playlistsearch.h
@@ -16,21 +16,21 @@
#ifndef PLAYLISTSEARCH_H
#define PLAYLISTSEARCH_H
-#include <qregexp.h>
+#include <tqregexp.h>
class Playlist;
-typedef QValueList<Playlist *> PlaylistList;
+typedef TQValueList<Playlist *> PlaylistList;
class PlaylistItem;
-typedef QValueList<PlaylistItem *> PlaylistItemList;
+typedef TQValueList<PlaylistItem *> PlaylistItemList;
-typedef QValueList<int> ColumnList;
+typedef TQValueList<int> ColumnList;
class PlaylistSearch
{
public:
class Component;
- typedef QValueList<Component> ComponentList;
+ typedef TQValueList<Component> ComponentList;
enum SearchMode { MatchAny = 0, MatchAll = 1 };
@@ -90,14 +90,14 @@ public:
/**
* Create an empty search component. This is only provided for use by
* QValueList and should not be used in any other context.
*/
Component();
/**
* Create a query component. This defaults to searching all visible coulumns.
*/
- Component(const QString &query,
+ Component(const TQString &query,
bool caseSensitive = false,
const ColumnList &columns = ColumnList(),
MatchMode mode = Contains);
@@ -105,10 +105,10 @@ public:
/**
* Create a query component. This defaults to searching all visible coulumns.
*/
- Component(const QRegExp &query, const ColumnList &columns = ColumnList());
+ Component(const TQRegExp &query, const ColumnList &columns = ColumnList());
- QString query() const { return m_query; }
- QRegExp pattern() const { return m_queryRe; }
+ TQString query() const { return m_query; }
+ TQRegExp pattern() const { return m_queryRe; }
ColumnList columns() const { return m_columns; }
bool matches(PlaylistItem *item) const;
@@ -119,8 +119,8 @@ public:
bool operator==(const Component &v) const;
private:
- QString m_query;
- QRegExp m_queryRe;
+ TQString m_query;
+ TQRegExp m_queryRe;
mutable ColumnList m_columns;
MatchMode m_mode;
bool m_searchAllVisible;
@@ -134,7 +134,7 @@ private:
* search is just relevant to the collection list. This is all that is presently
* needed by JuK.
*/
-QDataStream &operator<<(QDataStream &s, const PlaylistSearch &search);
+TQDataStream &operator<<(TQDataStream &s, const PlaylistSearch &search);
/**
* Streams \a search from the stream \a s.
@@ -142,9 +142,9 @@ QDataStream &operator<<(QDataStream &s, const PlaylistSearch &search);
* search is just relevant to the collection list. This is all that is presently
* needed by JuK.
*/
-QDataStream &operator>>(QDataStream &s, PlaylistSearch &search);
+TQDataStream &operator>>(TQDataStream &s, PlaylistSearch &search);
-QDataStream &operator<<(QDataStream &s, const PlaylistSearch::Component &c);
-QDataStream &operator>>(QDataStream &s, PlaylistSearch::Component &c);
+TQDataStream &operator<<(TQDataStream &s, const PlaylistSearch::Component &c);
+TQDataStream &operator>>(TQDataStream &s, PlaylistSearch::Component &c);
#endif
@@ -90,14 +90,14 @@ public:
/**
* Create an empty search component. This is only provided for use by
- * QValueList and should not be used in any other context.
+ * TQValueList and should not be used in any other context.
*/
Component();